<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.Grub2!message" line="0"/>
			<source>Authentication is required to change the grub2 configuration</source>
			<translation>Hitelesítés szükséges a grub2 konfiguráció módosítához </translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.Grub2!description" line="0"/>
			<source>Change the grub2 configuration</source>
			<translation>Módosítsa a grub2 konfigurációt</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.grub2.prepare-gfxmode-detect!message" line="0"/>
			<source>Authentication is required to prepare grub2 display resolution detection</source>
			<translation>Hitelesítés szükséges a grub2 képernyőfelbontás érzékeléshez</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.grub2.prepare-gfxmode-detect!description" line="0"/>
			<source>Prepare grub2 display resolution detection</source>
			<translation>Grub2 képernyőfelbontás érzékelés.</translation>
		</message>
	</context>
</TS>